@@ -368,5 +368,5 @@ def modify_version():
 
     print("Previous version: ", curr_version, "  New Version:: ", new_version, "   Type: ", __main__.change_type)
     
-    return __main__.sys.exit(0)
+    # return __main__.sys.exit(0)
   
\ No newline at end of file
